searchData={"items":[{"type":"module","doc":"Nebulex adapter for Redis. This adapter is implemented using `Redix`\n(a Redis driver for Elixir).\n\nThe adapter provides three setup alternatives:\n\n  * **Standalone** - The adapter establishes a pool of connections\n    with a single Redis node. The `:standalone` is the default mode.\n\n  * **Redis Cluster** - [Redis Cluster](https://redis.io/topics/cluster-tutorial)\n    is a built-in feature in Redis since version 3, and it may be the most\n    convenient and recommendable way to set up Redis in a cluster and have\n    a distributed cache storage out-of-box. This adapter provides the\n    `:redis_cluster` mode to set up **Redis Cluster** from the client-side\n    automatically and be able to use it transparently.\n\n  * **Built-in client-side cluster** - The `:client_side_cluster` mode\n    provides a simple client-side cluster implementation based on\n    sharding distribution model.","title":"Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html"},{"type":"module","doc":"A cache that uses Redis is defined as follows:\n\n    defmodule MyApp.RedisCache do\n      use Nebulex.Cache,\n        otp_app: :nebulex,\n        adapter: Nebulex.Adapters.Redis\n    end\n\nThe configuration for the cache must be in your application environment,\nusually defined in your `config/config.exs`:\n\n    config :my_app, MyApp.RedisCache,\n      conn_opts: [\n        host: \"127.0.0.1\",\n        port: 6379\n      ]","title":"Standalone - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-standalone"},{"type":"module","doc":"A cache that uses Redis Cluster can be defined as follows:\n\n    defmodule MyApp.RedisClusterCache do\n      use Nebulex.Cache,\n        otp_app: :nebulex,\n        adapter: Nebulex.Adapters.Redis\n    end\n\nAs you may notices, nothing has changed, it is defined the same as the\nstandalone mode. The change is in the configuration:\n\n    config :my_app, MyApp.RedisClusterCache,\n      mode: :redis_cluster,\n      redis_cluster: [\n        configuration_endpoints: [\n          endpoint1_conn_opts: [\n            host: \"127.0.0.1\",\n            port: 6379,\n            # Add the password if 'requirepass' is on\n            password: \"password\"\n          ],\n          ...\n        ]\n      ]","title":"Redis Cluster - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-redis-cluster"},{"type":"module","doc":"Same as the previous modes, a cache is defined as:\n\n    defmodule MyApp.ClusteredCache do\n      use Nebulex.Cache,\n        otp_app: :nebulex,\n        adapter: Nebulex.Adapters.Redis\n    end\n\nThe config:\n\n    config :my_app, MyApp.ClusteredCache,\n      mode: :client_side_cluster,\n      client_side_cluster: [\n        nodes: [\n          node1: [\n            pool_size: 10,\n            conn_opts: [\n              host: \"127.0.0.1\",\n              port: 9001\n            ]\n          ],\n          node2: [\n            pool_size: 4,\n            conn_opts: [\n              url: \"redis://127.0.0.1:9002\"\n            ]\n          ],\n          node3: [\n            conn_opts: [\n              host: \"127.0.0.1\",\n              port: 9003\n            ]\n          ],\n          ...\n        ]\n      ]\n\n> #### Redis Proxy Alternative {: .warning}\n>\n> Consider using a proxy instead, since it may provide more and better\n> features. See the \"Redis Proxy\" section below for more information.","title":"Client-side Cluster - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-client-side-cluster"},{"type":"module","doc":"Another option for \"Redis Cluster\" or the built-in \"Client-side cluster\" is\nusing a proxy such as [Envoy proxy][envoy] or [Twemproxy][twemproxy] on top\nof Redis. In this case, the proxy does the distribution work, and from the\nadparter's side (**Nebulex.Adapters.Redis**), it would be only configuration.\nInstead of connect the adapter against the Redis nodes, we connect it against\nthe proxy nodes, this means, in the config, we setup the pool with the host\nand port pointing to the proxy.\n\n[envoy]: https://www.envoyproxy.io/\n[twemproxy]: https://github.com/twitter/twemproxy","title":"Redis Proxy - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-redis-proxy"},{"type":"module","doc":"In addition to `Nebulex.Cache` config options, the adapter supports the\nfollowing options:\n\n* `:mode` - Redis configuration mode.\n\n    * `:standalone` - A single Redis instance. See the\n      [\"Standalone\"](#module-standalone) section in the\n      module documentation for more options.\n    * `:redis_cluster` - Redis Cluster setup. See the\n      [\"Redis Cluster\"](#module-redis-cluster) section in the\n      module documentation for more options.\n    * `:client_side_cluster` - See the\n      [\"Client-side Cluster\"](#module-client-side-cluster) section in the\n      module documentation for more options.\n\n  The default value is `:standalone`.\n\n* `:pool_size` (`t:pos_integer/0`) - The number of connections that will be started by the adapter\n  (based on the `:mode`). The default value is `System.schedulers_online()`.\n\n* `:serializer` - Custom serializer module implementing the `Nebulex.Adapters.Redis.Serializer`\n  behaviour.\n\n* `:serializer_opts` (`t:keyword/0`) - Custom serializer options. The default value is `[]`.\n\n  * `:encode_key` (`t:keyword/0`) - Options for encoding the key. The default value is `[]`.\n\n  * `:encode_value` (`t:keyword/0`) - Options for encoding the value. The default value is `[]`.\n\n  * `:decode_key` (`t:keyword/0`) - Options for decoding the key. The default value is `[]`.\n\n  * `:decode_value` (`t:keyword/0`) - Options for decoding the value. The default value is `[]`.\n\n* `:conn_opts` (`t:keyword/0`) - Redis client options. See `Redix` docs for more information\n  about the options. The default value is `[host: \"127.0.0.1\", port: 6379]`.\n\n* `:redis_cluster` - Required only when `:mode` is set to `:redis_cluster`. A keyword list of\n  options.\n\n  See [\"Redis Cluster options\"](#module-redis-cluster-options)\n  section below.\n\n* `:client_side_cluster` - Required only when `:mode` is set to `:client_side_cluster`. A keyword\n  list of options.\n\n  See [\"Client-side Cluster options\"](#module-client-side-cluster-options)\n  section below.","title":"Configuration options - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-configuration-options"},{"type":"module","doc":"The available options are:\n\n* `:configuration_endpoints` - Required. A keyword list of named endpoints where the key is an atom as\n  an identifier and the value is another keyword list of options\n  (same as `:conn_opts`).\n\n  See [\"Redis Cluster\"](#module-redis-cluster) for more information.\n\n* `:override_master_host` (`t:boolean/0`) - Defines whether the given master host should be overridden with the\n  configuration endpoint or not. Defaults to `false`.\n\n  The adapter uses the host returned by the **\"CLUSTER SHARDS\"**\n  (Redis >= 7) or **\"CLUSTER SLOTS\"** (Redis < 7) command. One may\n  consider set it to `true` for tests when using Docker for example,\n  or when Redis nodes are behind a load balancer that Redis doesn't\n  know the endpoint of. See Redis docs for more information.\n\n  The default value is `false`.\n\n* `:keyslot` (function of arity 2) - A function to compute the hash slot for a given key and range. The default value is `&Nebulex.Adapters.Redis.Cluster.Keyslot.hash_slot/2`.","title":"Redis Cluster options - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-redis-cluster-options"},{"type":"module","doc":"The available options are:\n\n* `:nodes` - Required. A keyword list of named nodes where the key is an atom as\n  an identifier and the value is another keyword list of options\n  (same as `:conn_opts`).\n\n  See [\"Client-side Cluster\"](#module-client-side-cluster)\n  for more information.","title":"Client-side Cluster options - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-client-side-cluster-options"},{"type":"module","doc":"Since the adapter runs on top of `Redix`, all commands accept their options\n(e.g.: `:timeout`, and `:telemetry_metadata`). See `Redix` docs for more\ninformation.","title":"Shared runtime options - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-shared-runtime-options"},{"type":"module","doc":"The following options are only for the `:redis_cluster` mode and apply to all\ncommands:\n\n  * `:lock_retries` -  When the config manager is running and setting up\n    the hash slot map, all Redis commands get blocked until the cluster\n    is properly configured and the hash slot map is ready to use. This\n    option defines the max retry attempts to acquire the lock before\n    executing the command. Defaults to `:infinity`.","title":"Redis Cluster runtime options - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-redis-cluster-runtime-options"},{"type":"module","doc":"Since the queryable API is implemented by using `KEYS` command,\nkeep in mind the following caveats:\n\n  * Only keys can be queried.\n  * Only strings and predefined queries are allowed as query values.\n\nSee [\"KEYS\" command](https://redis.io/docs/latest/commands/keys/).","title":"Query API - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-query-api"},{"type":"module","doc":"iex> MyApp.RedisCache.put_all(%{\n    ...>   \"firstname\" => \"Albert\",\n    ...>   \"lastname\" => \"Einstein\",\n    ...>   \"age\" => 76\n    ...> })\n    :ok\n\n    # returns key/value pairs by default\n    iex> MyApp.RedisCache.get_all!(\"**name**\") |> Map.new()\n    %{\"firstname\" => \"Albert\", \"lastname\" => \"Einstein\"}\n\n    iex> MyApp.RedisCache.get_all!(\"**name**\", select: :key)\n    [\"firstname\", \"lastname\"]\n\n    iex> MyApp.RedisCache.get_all!(\"a??\", select: :key)\n    [\"age\"]\n\n    iex> MyApp.RedisCache.get_all!(select: :key)\n    [\"age\", \"firstname\", \"lastname\"]\n\n    iex> MyApp.RedisCache.stream!(\"**name**\", select: :key) |> Enum.to_list()\n    [\"firstname\", \"lastname\"]","title":"Examples - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-examples"},{"type":"module","doc":"iex> MyApp.RedisCache.delete_all!({:in, [\"foo\", \"bar\"]})\n    2\n    iex> MyApp.RedisCache.count_all!({:in, [\"foo\", \"bar\"]})\n    2","title":"Deleting/counting keys - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-deleting-counting-keys"},{"type":"module","doc":"> #### Transactions {: .info}\n>\n> Transaction support is not currently available in this adapter,\n> but it is planned for future releases.","title":"Transactions - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-transactions"},{"type":"module","doc":"Since the Redis adapter works on top of `Redix` and provides features like\nconnection pools, \"Redis Cluster\", etc., it may also work as a Redis client.\nThe Redis API is quite extensive, and there are many useful commands we may\nwant to run, leveraging the Redis adapter features. Therefore, the adapter\nprovides additional functions to do so.\n\n### `fetch_conn(opts \\\\ [])`\n\nThe function accepts the following options:\n\n* `:name` (`t:atom/0`) - The name of the cache (in case you are using dynamic caches),\n  otherwise it is not required (defaults to the cache module name).\n\n* `:key` (`t:term/0`) - The key is used to compute the node where the command will be executed.\n  It is only required for `:redis_cluster` and `:client_side_cluster` modes.\n\n\n\nLet's see some examples:\n\n    iex> MyCache.fetch_conn!()\n    ...> |> Redix.command!([\"LPUSH\", \"mylist\", \"hello\"])\n    1\n    iex> MyCache.fetch_conn!()\n    ...> |> Redix.command!([\"LPUSH\", \"mylist\", \"world\"])\n    2\n    iex> MyCache.fetch_conn!()\n    ...> |> Redix.command!([\"LRANGE\", \"mylist\", \"0\", \"-1\"])\n    [\"hello\", \"world\"]\n\nWhen working with `:redis_cluster` or `:client_side_cluster` modes the option\n`:key` is required:\n\n    iex> {:ok, conn} = MyCache.fetch_conn(key: \"mylist\")\n    iex> Redix.pipeline!([\n    ...>   [\"LPUSH\", \"mylist\", \"hello\"],\n    ...>   [\"LPUSH\", \"mylist\", \"world\"],\n    ...>   [\"LRANGE\", \"mylist\", \"0\", \"-1\"]\n    ...> ])\n    [1, 2, [\"hello\", \"world\"]]\n\nSince these functions run on top of `Redix`, they also accept their options\n(e.g.: `:timeout`, and `:telemetry_metadata`). See `Redix` docs for more\ninformation.","title":"Using the adapter as a Redis client - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-using-the-adapter-as-a-redis-client"},{"type":"module","doc":"The following functions are available to encode/decode Elixir terms. It is\nuseful whenever you want to work with Elixir terms in addition to strings\nor other specific Redis data types.\n\n  * `encode_key(name \\\\ __MODULE__, key)` - Encodes an Elixir term into a\n    string. The argument `name` is optional and should be used in case of\n    dynamic caches (Defaults to the defined cache module).\n  * `encode_value(name \\\\ __MODULE__, value)` - Same as `encode_key` but\n    it is specific for encoding values, in case the encoding for keys and\n    values are different.\n  * `decode_key(name \\\\ __MODULE__, key)` - Decodes binary into an Elixir\n    term. The argument `name` is optional and should be used in case of\n    dynamic caches (Defaults to the defined cache module).\n  * `decode_value(name \\\\ __MODULE__, value)` - Same as `decode_key` but\n    it is specific for decoding values, in case the decoding for keys and\n    values are different.\n\nLet's see some examples:\n\n    iex> conn = MyCache.fetch_conn!()\n    iex> key = MyCache.encode_key({:key, \"key\"})\n    iex> value = MyCache.encode_value({:value, \"value\"})\n    iex> Redix.command!(conn, [\"SET\", key, value], timeout: 5000)\n    \"OK\"\n    iex> Redix.command!(conn, [\"GET\", key]) |> MyCache.decode_value()\n    {:value, \"value\"}","title":"Encoding/decoding functions - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-encoding-decoding-functions"},{"type":"module","doc":"Aside from the recommended Telemetry events by `Nebulex.Cache`, this adapter\nexposes the following Telemetry events for the `:redis_cluster` mode:\n\n  * `telemetry_prefix ++ [:redis_cluster, :setup, :start]` - This event is\n    specific to the `:redis_cluster` mode. Before the configuration manager\n    calls Redis to set up the cluster shards, this event should be invoked.\n\n    The `:measurements` map will include the following:\n\n    * `:system_time` - The current system time in native units from calling:\n      `System.system_time()`.\n\n    A Telemetry `:metadata` map including the following fields:\n\n    * `:adapter_meta` - The adapter metadata.\n    * `:pid` - The configuration manager PID.\n\n  * `telemetry_prefix ++ [:redis_cluster, :setup, :stop]` - This event is\n    specific to the `:redis_cluster` mode. After the configuration manager\n    set up the cluster shards, this event should be invoked.\n\n    The `:measurements` map will include the following:\n\n    * `:duration` - The time spent configuring the cluster. The measurement\n      is given in the `:native` time unit. You can read more about it in the\n      docs for `System.convert_time_unit/3`.\n\n    A Telemetry `:metadata` map including the following fields:\n\n    * `:adapter_meta` - The adapter metadata.\n    * `:pid` - The configuration manager PID.\n    * `:status` - The cluster setup status. If the cluster was configured\n      successfully, the status will be set to `:ok`, otherwise, will be\n      set to `:error`.\n    * `:reason` - The status reason. When the status is `:ok`, the reason is\n      `:succeeded`, otherwise, it is the error reason.\n\n  * `telemetry_prefix ++ [:redis_cluster, :setup, :exception]` - This event\n    is specific to the `:redis_cluster` mode. When an exception is raised\n    while configuring the cluster, this event should be invoked.\n\n    The `:measurements` map will include the following:\n\n    * `:duration` - The time spent configuring the cluster. The measurement\n      is given in the `:native` time unit. You can read more about it in the\n      docs for `System.convert_time_unit/3`.\n\n    A Telemetry `:metadata` map including the following fields:\n\n    * `:adapter_meta` - The adapter metadata.\n    * `:pid` - The configuration manager PID.\n    * `:kind` - The type of the error: `:error`, `:exit`, or `:throw`.\n    * `:reason` - The reason of the error.\n    * `:stacktrace` - The stacktrace.","title":"Adapter-specific telemetry events for the :redis_cluster mode - Nebulex.Adapters.Redis","ref":"Nebulex.Adapters.Redis.html#module-adapter-specific-telemetry-events-for-the-redis_cluster-mode"},{"type":"module","doc":"Client-side Cluster","title":"Nebulex.Adapters.Redis.ClientSideCluster","ref":"Nebulex.Adapters.Redis.ClientSideCluster.html"},{"type":"type","doc":"Proxy type to the adapter meta","title":"Nebulex.Adapters.Redis.ClientSideCluster.adapter_meta/0","ref":"Nebulex.Adapters.Redis.ClientSideCluster.html#t:adapter_meta/0"},{"type":"function","doc":"","title":"Nebulex.Adapters.Redis.ClientSideCluster.command/5","ref":"Nebulex.Adapters.Redis.ClientSideCluster.html#command/5"},{"type":"function","doc":"","title":"Nebulex.Adapters.Redis.ClientSideCluster.fetch_conn/3","ref":"Nebulex.Adapters.Redis.ClientSideCluster.html#fetch_conn/3"},{"type":"function","doc":"","title":"Nebulex.Adapters.Redis.ClientSideCluster.group_keys_by_hash_slot/3","ref":"Nebulex.Adapters.Redis.ClientSideCluster.html#group_keys_by_hash_slot/3"},{"type":"function","doc":"","title":"Nebulex.Adapters.Redis.ClientSideCluster.init/2","ref":"Nebulex.Adapters.Redis.ClientSideCluster.html#init/2"},{"type":"type","doc":"","title":"Nebulex.Adapters.Redis.ClientSideCluster.node_entry/0","ref":"Nebulex.Adapters.Redis.ClientSideCluster.html#t:node_entry/0"},{"type":"type","doc":"","title":"Nebulex.Adapters.Redis.ClientSideCluster.nodes_config/0","ref":"Nebulex.Adapters.Redis.ClientSideCluster.html#t:nodes_config/0"},{"type":"module","doc":"Redis Cluster Manager","title":"Nebulex.Adapters.Redis.Cluster","ref":"Nebulex.Adapters.Redis.Cluster.html"},{"type":"type","doc":"Proxy type to the adapter meta","title":"Nebulex.Adapters.Redis.Cluster.adapter_meta/0","ref":"Nebulex.Adapters.Redis.Cluster.html#t:adapter_meta/0"},{"type":"function","doc":"","title":"Nebulex.Adapters.Redis.Cluster.command/5","ref":"Nebulex.Adapters.Redis.Cluster.html#command/5"},{"type":"function","doc":"","title":"Nebulex.Adapters.Redis.Cluster.del_status_key/1","ref":"Nebulex.Adapters.Redis.Cluster.html#del_status_key/1"},{"type":"function","doc":"","title":"Nebulex.Adapters.Redis.Cluster.fetch_conn/3","ref":"Nebulex.Adapters.Redis.Cluster.html#fetch_conn/3"},{"type":"function","doc":"","title":"Nebulex.Adapters.Redis.Cluster.get_status/2","ref":"Nebulex.Adapters.Redis.Cluster.html#get_status/2"},{"type":"function","doc":"","title":"Nebulex.Adapters.Redis.Cluster.group_keys_by_hash_slot/3","ref":"Nebulex.Adapters.Redis.Cluster.html#group_keys_by_hash_slot/3"},{"type":"function","doc":"","title":"Nebulex.Adapters.Redis.Cluster.hash_slot/2","ref":"Nebulex.Adapters.Redis.Cluster.html#hash_slot/2"},{"type":"function","doc":"","title":"Nebulex.Adapters.Redis.Cluster.init/2","ref":"Nebulex.Adapters.Redis.Cluster.html#init/2"},{"type":"function","doc":"","title":"Nebulex.Adapters.Redis.Cluster.put_status/2","ref":"Nebulex.Adapters.Redis.Cluster.html#put_status/2"},{"type":"function","doc":"","title":"Nebulex.Adapters.Redis.Cluster.with_retry/3","ref":"Nebulex.Adapters.Redis.Cluster.html#with_retry/3"},{"type":"module","doc":"Default `Nebulex.Adapter.Keyslot` implementation.","title":"Nebulex.Adapters.Redis.Cluster.Keyslot","ref":"Nebulex.Adapters.Redis.Cluster.Keyslot.html"},{"type":"function","doc":"Helper function to compute the key; regardless the key contains hashtags\nor not.","title":"Nebulex.Adapters.Redis.Cluster.Keyslot.compute_key/1","ref":"Nebulex.Adapters.Redis.Cluster.Keyslot.html#compute_key/1"},{"type":"type","doc":"Keyslot funtion type","title":"Nebulex.Adapters.Redis.Cluster.Keyslot.t/0","ref":"Nebulex.Adapters.Redis.Cluster.Keyslot.html#t:t/0"},{"type":"module","doc":"Redis Cluster shard supervisor.","title":"Nebulex.Adapters.Redis.Cluster.PoolSupervisor","ref":"Nebulex.Adapters.Redis.Cluster.PoolSupervisor.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"Nebulex.Adapters.Redis.Cluster.PoolSupervisor.child_spec/1","ref":"Nebulex.Adapters.Redis.Cluster.PoolSupervisor.html#child_spec/1"},{"type":"module","doc":"Adapter error formatter.","title":"Nebulex.Adapters.Redis.ErrorFormatter","ref":"Nebulex.Adapters.Redis.ErrorFormatter.html"},{"type":"behaviour","doc":"A **Serializer** encodes keys and values sent to Redis,\nand decodes keys and values in the command output.\n\nSee [Redis Strings](https://redis.io/docs/data-types/strings/).","title":"Nebulex.Adapters.Redis.Serializer","ref":"Nebulex.Adapters.Redis.Serializer.html"},{"type":"callback","doc":"Decodes `key` with the given `opts`.","title":"Nebulex.Adapters.Redis.Serializer.decode_key/2","ref":"Nebulex.Adapters.Redis.Serializer.html#c:decode_key/2"},{"type":"callback","doc":"Decodes `value` with the given `opts`.","title":"Nebulex.Adapters.Redis.Serializer.decode_value/2","ref":"Nebulex.Adapters.Redis.Serializer.html#c:decode_value/2"},{"type":"callback","doc":"Encodes `key` with the given `opts`.","title":"Nebulex.Adapters.Redis.Serializer.encode_key/2","ref":"Nebulex.Adapters.Redis.Serializer.html#c:encode_key/2"},{"type":"callback","doc":"Encodes `value` with the given `opts`.","title":"Nebulex.Adapters.Redis.Serializer.encode_value/2","ref":"Nebulex.Adapters.Redis.Serializer.html#c:encode_value/2"},{"type":"protocol","doc":"Protocol controlling how a key/value is encoded to a string\nand how a string is decoded into an Elixir any().\n\nSee [Redis Strings](https://redis.io/docs/data-types/strings/).","title":"Nebulex.Adapters.Redis.Serializer.Serializable","ref":"Nebulex.Adapters.Redis.Serializer.Serializable.html"},{"type":"function","doc":"Decodes `data` with the given `opts`.","title":"Nebulex.Adapters.Redis.Serializer.Serializable.decode/2","ref":"Nebulex.Adapters.Redis.Serializer.Serializable.html#decode/2"},{"type":"function","doc":"Encodes `data` with the given `opts`.","title":"Nebulex.Adapters.Redis.Serializer.Serializable.encode/2","ref":"Nebulex.Adapters.Redis.Serializer.Serializable.html#encode/2"},{"type":"type","doc":"All the types that implement this protocol.","title":"Nebulex.Adapters.Redis.Serializer.Serializable.t/0","ref":"Nebulex.Adapters.Redis.Serializer.Serializable.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.0"}}